/* TimedQueue.c generated by valac 0.18.1, the Vala compiler
 * generated from TimedQueue.vala, do not modify */

/* Copyright 2010-2013 Yorba Foundation
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */
/* TimedQueue is a specialized collection class.  It holds items in order, but rather than being*/
/* manually dequeued, they are dequeued automatically after a specified amount of time has elapsed*/
/* for that item.  As of today, it's possible the item will be dequeued a bit later than asked*/
/* for, but it will never be early.  Future implementations might tighten up the lateness.*/
/**/
/* The original design was to use a signal to notify when an item has been dequeued, but Vala has*/
/* a bug with passing an unnamed type as a signal parameter:*/
/* https://bugzilla.gnome.org/show_bug.cgi?id=628639*/
/**/
/* The rate the items come off the queue can be spaced out.  Note that this can cause items to back*/
/* up.  As of today, TimedQueue makes no effort to combat this.*/

#include <glib.h>
#include <glib-object.h>
#include <gee.h>
#include <gobject/gvaluecollector.h>


#define TYPE_TIMED_QUEUE (timed_queue_get_type ())
#define TIMED_QUEUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TIMED_QUEUE, TimedQueue))
#define TIMED_QUEUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TIMED_QUEUE, TimedQueueClass))
#define IS_TIMED_QUEUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TIMED_QUEUE))
#define IS_TIMED_QUEUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TIMED_QUEUE))
#define TIMED_QUEUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TIMED_QUEUE, TimedQueueClass))

typedef struct _TimedQueue TimedQueue;
typedef struct _TimedQueueClass TimedQueueClass;
typedef struct _TimedQueuePrivate TimedQueuePrivate;

#define TYPE_SORTED_LIST (sorted_list_get_type ())
#define SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SORTED_LIST, SortedList))
#define SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SORTED_LIST, SortedListClass))
#define IS_SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SORTED_LIST))
#define IS_SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SORTED_LIST))
#define SORTED_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SORTED_LIST, SortedListClass))

typedef struct _SortedList SortedList;
typedef struct _SortedListClass SortedListClass;

#define TIMED_QUEUE_TYPE_ELEMENT (timed_queue_element_get_type ())
#define TIMED_QUEUE_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TIMED_QUEUE_TYPE_ELEMENT, TimedQueueElement))
#define TIMED_QUEUE_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TIMED_QUEUE_TYPE_ELEMENT, TimedQueueElementClass))
#define TIMED_QUEUE_IS_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TIMED_QUEUE_TYPE_ELEMENT))
#define TIMED_QUEUE_IS_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TIMED_QUEUE_TYPE_ELEMENT))
#define TIMED_QUEUE_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TIMED_QUEUE_TYPE_ELEMENT, TimedQueueElementClass))

typedef struct _TimedQueueElement TimedQueueElement;
typedef struct _TimedQueueElementClass TimedQueueElementClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _TimedQueueElementPrivate TimedQueueElementPrivate;
#define _timed_queue_element_unref0(var) ((var == NULL) ? NULL : (var = (timed_queue_element_unref (var), NULL)))
#define _g_destroy_func0(var) (((var == NULL) || (g_destroy_func == NULL)) ? NULL : (var = (g_destroy_func (var), NULL)))
typedef struct _TimedQueueParamSpecElement TimedQueueParamSpecElement;
typedef struct _ParamSpecTimedQueue ParamSpecTimedQueue;

#define TYPE_HASH_TIMED_QUEUE (hash_timed_queue_get_type ())
#define HASH_TIMED_QUEUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HASH_TIMED_QUEUE, HashTimedQueue))
#define HASH_TIMED_QUEUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HASH_TIMED_QUEUE, HashTimedQueueClass))
#define IS_HASH_TIMED_QUEUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HASH_TIMED_QUEUE))
#define IS_HASH_TIMED_QUEUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HASH_TIMED_QUEUE))
#define HASH_TIMED_QUEUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HASH_TIMED_QUEUE, HashTimedQueueClass))

typedef struct _HashTimedQueue HashTimedQueue;
typedef struct _HashTimedQueueClass HashTimedQueueClass;
typedef struct _HashTimedQueuePrivate HashTimedQueuePrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef void (*DequeuedCallback) (gconstpointer item, void* user_data);
struct _TimedQueue {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TimedQueuePrivate * priv;
};

struct _TimedQueueClass {
	GTypeClass parent_class;
	void (*finalize) (TimedQueue *self);
	void (*notify_dequeued) (TimedQueue* self, gconstpointer item);
	void (*clear) (TimedQueue* self);
	gboolean (*contains) (TimedQueue* self, gconstpointer item);
	gboolean (*enqueue) (TimedQueue* self, gconstpointer item);
	gboolean (*enqueue_many) (TimedQueue* self, GeeCollection* items);
	gboolean (*remove_first) (TimedQueue* self, gconstpointer item);
	void (*paused) (TimedQueue* self, gboolean is_paused);
	gint (*get_size) (TimedQueue* self);
};

struct _TimedQueuePrivate {
	GType g_type;
	GBoxedCopyFunc g_dup_func;
	GDestroyNotify g_destroy_func;
	guint hold_msec;
	DequeuedCallback callback;
	gpointer callback_target;
	GEqualFunc equal_func;
	gint priority;
	guint timer_id;
	SortedList* queue;
	guint dequeue_spacing_msec;
	gulong last_dequeue;
	gboolean paused_state;
};

typedef gint64 (*Comparator) (void* a, void* b, void* user_data);
struct _TimedQueueElement {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TimedQueueElementPrivate * priv;
	gpointer item;
	gulong ready;
};

struct _TimedQueueElementClass {
	GTypeClass parent_class;
	void (*finalize) (TimedQueueElement *self);
};

struct _TimedQueueElementPrivate {
	GType g_type;
	GBoxedCopyFunc g_dup_func;
	GDestroyNotify g_destroy_func;
};

struct _TimedQueueParamSpecElement {
	GParamSpec parent_instance;
};

struct _ParamSpecTimedQueue {
	GParamSpec parent_instance;
};

struct _HashTimedQueue {
	TimedQueue parent_instance;
	HashTimedQueuePrivate * priv;
};

struct _HashTimedQueueClass {
	TimedQueueClass parent_class;
};

struct _HashTimedQueuePrivate {
	GType g_type;
	GBoxedCopyFunc g_dup_func;
	GDestroyNotify g_destroy_func;
	GeeHashMap* item_count;
};


static gpointer timed_queue_parent_class = NULL;
static gpointer timed_queue_element_parent_class = NULL;
static gpointer hash_timed_queue_parent_class = NULL;

gpointer timed_queue_ref (gpointer instance);
void timed_queue_unref (gpointer instance);
GParamSpec* param_spec_timed_queue (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_timed_queue (GValue* value, gpointer v_object);
void value_take_timed_queue (GValue* value, gpointer v_object);
gpointer value_get_timed_queue (const GValue* value);
GType timed_queue_get_type (void) G_GNUC_CONST;
GType sorted_list_get_type (void) G_GNUC_CONST;
static gpointer timed_queue_element_ref (gpointer instance);
static void timed_queue_element_unref (gpointer instance);
static GParamSpec* timed_queue_param_spec_element (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void timed_queue_value_set_element (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void timed_queue_value_take_element (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer timed_queue_value_get_element (const GValue* value) G_GNUC_UNUSED;
static GType timed_queue_element_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define TIMED_QUEUE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TIMED_QUEUE, TimedQueuePrivate))
enum  {
	TIMED_QUEUE_DUMMY_PROPERTY
};
TimedQueue* timed_queue_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, guint hold_msec, DequeuedCallback callback, void* callback_target, GEqualFunc equal_func, gint priority);
TimedQueue* timed_queue_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, guint hold_msec, DequeuedCallback callback, void* callback_target, GEqualFunc equal_func, gint priority);
static gint64 timed_queue_element_comparator (void* a, void* b);
static gint64 _timed_queue_element_comparator_comparator (void* a, void* b, gpointer self);
SortedList* sorted_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, Comparator cmp, void* cmp_target);
SortedList* sorted_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, Comparator cmp, void* cmp_target);
static guint timed_queue_get_heartbeat_timeout (TimedQueue* self);
static gboolean timed_queue_on_heartbeat (TimedQueue* self);
static gboolean _timed_queue_on_heartbeat_gsource_func (gpointer self);
guint timed_queue_get_dequeue_spacing_msec (TimedQueue* self);
void timed_queue_set_dequeue_spacing_msec (TimedQueue* self, guint msec);
void timed_queue_notify_dequeued (TimedQueue* self, gconstpointer item);
static void timed_queue_real_notify_dequeued (TimedQueue* self, gconstpointer item);
gboolean timed_queue_is_paused (TimedQueue* self);
void timed_queue_pause (TimedQueue* self);
void timed_queue_unpause (TimedQueue* self);
void timed_queue_clear (TimedQueue* self);
static void timed_queue_real_clear (TimedQueue* self);
gboolean timed_queue_contains (TimedQueue* self, gconstpointer item);
static gboolean timed_queue_real_contains (TimedQueue* self, gconstpointer item);
gboolean timed_queue_enqueue (TimedQueue* self, gconstpointer item);
static gboolean timed_queue_real_enqueue (TimedQueue* self, gconstpointer item);
static gulong timed_queue_calc_ready_time (TimedQueue* self);
static TimedQueueElement* timed_queue_element_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, gconstpointer item, gulong ready);
static TimedQueueElement* timed_queue_element_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, gconstpointer item, gulong ready);
gboolean timed_queue_enqueue_many (TimedQueue* self, GeeCollection* items);
static gboolean timed_queue_real_enqueue_many (TimedQueue* self, GeeCollection* items);
gboolean sorted_list_add_list (SortedList* self, GeeList* items);
gboolean timed_queue_remove_first (TimedQueue* self, gconstpointer item);
static gboolean timed_queue_real_remove_first (TimedQueue* self, gconstpointer item);
gulong now_ms (void);
gpointer sorted_list_get_at (SortedList* self, gint index);
gpointer sorted_list_remove_at (SortedList* self, gint index);
gint timed_queue_get_size (TimedQueue* self);
static void timed_queue_real_paused (TimedQueue* self, gboolean is_paused);
#define TIMED_QUEUE_ELEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TIMED_QUEUE_TYPE_ELEMENT, TimedQueueElementPrivate))
enum  {
	TIMED_QUEUE_ELEMENT_DUMMY_PROPERTY
};
static void timed_queue_element_finalize (TimedQueueElement* obj);
static void timed_queue_finalize (TimedQueue* obj);
GType hash_timed_queue_get_type (void) G_GNUC_CONST;
#define HASH_TIMED_QUEUE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_HASH_TIMED_QUEUE, HashTimedQueuePrivate))
enum  {
	HASH_TIMED_QUEUE_DUMMY_PROPERTY
};
HashTimedQueue* hash_timed_queue_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, guint hold_msec, DequeuedCallback callback, void* callback_target, GHashFunc hash_func, GEqualFunc equal_func, gint priority);
HashTimedQueue* hash_timed_queue_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, guint hold_msec, DequeuedCallback callback, void* callback_target, GHashFunc hash_func, GEqualFunc equal_func, gint priority);
static void hash_timed_queue_real_notify_dequeued (TimedQueue* base, gconstpointer item);
static void hash_timed_queue_removed (HashTimedQueue* self, gconstpointer item);
static void hash_timed_queue_real_clear (TimedQueue* base);
static gboolean hash_timed_queue_real_contains (TimedQueue* base, gconstpointer item);
static gboolean hash_timed_queue_real_enqueue (TimedQueue* base, gconstpointer item);
static gboolean hash_timed_queue_real_enqueue_many (TimedQueue* base, GeeCollection* items);
static gboolean hash_timed_queue_real_remove_first (TimedQueue* base, gconstpointer item);
static void hash_timed_queue_finalize (TimedQueue* obj);


static gint64 _timed_queue_element_comparator_comparator (void* a, void* b, gpointer self) {
	gint64 result;
	result = timed_queue_element_comparator (a, b);
#line 59 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 244 "TimedQueue.c"
}


static gboolean _timed_queue_on_heartbeat_gsource_func (gpointer self) {
	gboolean result;
	result = timed_queue_on_heartbeat (self);
#line 61 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 253 "TimedQueue.c"
}


TimedQueue* timed_queue_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, guint hold_msec, DequeuedCallback callback, void* callback_target, GEqualFunc equal_func, gint priority) {
	TimedQueue* self = NULL;
	guint _tmp0_;
	DequeuedCallback _tmp1_;
	void* _tmp1__target;
	GEqualFunc _tmp2_ = NULL;
	GEqualFunc _tmp3_;
	GEqualFunc _tmp6_;
	gint _tmp7_;
	SortedList* _tmp8_;
	guint _tmp9_ = 0U;
	gint _tmp10_;
	guint _tmp11_ = 0U;
#line 52 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = (TimedQueue*) g_type_create_instance (object_type);
#line 52 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_type = g_type;
#line 52 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_dup_func = g_dup_func;
#line 52 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_destroy_func = g_destroy_func;
#line 54 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = hold_msec;
#line 54 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->hold_msec = _tmp0_;
#line 55 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = callback;
#line 55 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1__target = callback_target;
#line 55 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->callback = _tmp1_;
#line 55 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->callback_target = _tmp1__target;
#line 56 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp3_ = equal_func;
#line 56 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp3_ != NULL) {
#line 294 "TimedQueue.c"
		GEqualFunc _tmp4_;
#line 56 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp4_ = equal_func;
#line 56 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp2_ = _tmp4_;
#line 300 "TimedQueue.c"
	} else {
		GEqualFunc _tmp5_ = NULL;
#line 56 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp5_ = gee_functions_get_equal_func_for (g_type);
#line 56 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp2_ = _tmp5_;
#line 307 "TimedQueue.c"
	}
#line 56 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp6_ = _tmp2_;
#line 56 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->equal_func = _tmp6_;
#line 57 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp7_ = priority;
#line 57 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->priority = _tmp7_;
#line 59 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp8_ = sorted_list_new (TIMED_QUEUE_TYPE_ELEMENT, (GBoxedCopyFunc) timed_queue_element_ref, timed_queue_element_unref, _timed_queue_element_comparator_comparator, NULL);
#line 59 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_g_object_unref0 (self->priv->queue);
#line 59 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->queue = _tmp8_;
#line 61 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp9_ = timed_queue_get_heartbeat_timeout (self);
#line 61 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp10_ = priority;
#line 61 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp11_ = g_timeout_add_full (_tmp10_, _tmp9_, _timed_queue_on_heartbeat_gsource_func, timed_queue_ref (self), timed_queue_unref);
#line 61 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->timer_id = _tmp11_;
#line 52 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return self;
#line 333 "TimedQueue.c"
}


TimedQueue* timed_queue_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, guint hold_msec, DequeuedCallback callback, void* callback_target, GEqualFunc equal_func, gint priority) {
#line 52 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return timed_queue_construct (TYPE_TIMED_QUEUE, g_type, g_dup_func, g_destroy_func, hold_msec, callback, callback_target, equal_func, priority);
#line 340 "TimedQueue.c"
}


guint timed_queue_get_dequeue_spacing_msec (TimedQueue* self) {
	guint result = 0U;
	guint _tmp0_;
#line 69 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), 0U);
#line 70 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->dequeue_spacing_msec;
#line 70 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = _tmp0_;
#line 70 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 355 "TimedQueue.c"
}


void timed_queue_set_dequeue_spacing_msec (TimedQueue* self, guint msec) {
	guint _tmp0_;
	guint _tmp1_;
	guint _tmp2_;
	guint _tmp4_;
	guint _tmp5_ = 0U;
	gint _tmp6_;
	guint _tmp7_ = 0U;
#line 73 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (IS_TIMED_QUEUE (self));
#line 74 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = msec;
#line 74 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = self->priv->dequeue_spacing_msec;
#line 74 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp0_ == _tmp1_) {
#line 75 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return;
#line 377 "TimedQueue.c"
	}
#line 77 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = self->priv->timer_id;
#line 77 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 383 "TimedQueue.c"
		guint _tmp3_;
#line 78 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp3_ = self->priv->timer_id;
#line 78 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_source_remove (_tmp3_);
#line 389 "TimedQueue.c"
	}
#line 80 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp4_ = msec;
#line 80 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->dequeue_spacing_msec = _tmp4_;
#line 82 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp5_ = timed_queue_get_heartbeat_timeout (self);
#line 82 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp6_ = self->priv->priority;
#line 82 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp7_ = g_timeout_add_full (_tmp6_, _tmp5_, _timed_queue_on_heartbeat_gsource_func, timed_queue_ref (self), timed_queue_unref);
#line 82 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->timer_id = _tmp7_;
#line 403 "TimedQueue.c"
}


static guint timed_queue_get_heartbeat_timeout (TimedQueue* self) {
	guint result = 0U;
	guint _tmp0_ = 0U;
	guint _tmp1_;
	guint _tmp4_;
	guint _tmp5_;
	guint _tmp6_ = 0U;
#line 85 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), 0U);
#line 86 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = self->priv->dequeue_spacing_msec;
#line 86 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp1_ == ((guint) 0)) {
#line 420 "TimedQueue.c"
		guint _tmp2_;
#line 87 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp2_ = self->priv->hold_msec;
#line 87 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp0_ = _tmp2_ / 10;
#line 426 "TimedQueue.c"
	} else {
		guint _tmp3_;
#line 88 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp3_ = self->priv->dequeue_spacing_msec;
#line 88 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp0_ = _tmp3_ / 2;
#line 433 "TimedQueue.c"
	}
#line 86 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp4_ = _tmp0_;
#line 86 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp5_ = G_MAXUINT;
#line 86 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp6_ = CLAMP (_tmp4_, (guint) 10, _tmp5_);
#line 86 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = _tmp6_;
#line 86 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 445 "TimedQueue.c"
}


static void timed_queue_real_notify_dequeued (TimedQueue* self, gconstpointer item) {
	DequeuedCallback _tmp0_;
	void* _tmp0__target;
	gconstpointer _tmp1_;
#line 92 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->callback;
#line 92 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0__target = self->priv->callback_target;
#line 92 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = item;
#line 92 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ (_tmp1_, _tmp0__target);
#line 461 "TimedQueue.c"
}


void timed_queue_notify_dequeued (TimedQueue* self, gconstpointer item) {
#line 91 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (IS_TIMED_QUEUE (self));
#line 91 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_GET_CLASS (self)->notify_dequeued (self, item);
#line 470 "TimedQueue.c"
}


gboolean timed_queue_is_paused (TimedQueue* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 95 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), FALSE);
#line 96 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->paused_state;
#line 96 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = _tmp0_;
#line 96 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 485 "TimedQueue.c"
}


void timed_queue_pause (TimedQueue* self) {
	gboolean _tmp0_;
#line 99 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (IS_TIMED_QUEUE (self));
#line 100 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->paused_state;
#line 100 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp0_) {
#line 101 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return;
#line 499 "TimedQueue.c"
	}
#line 103 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->paused_state = TRUE;
#line 105 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_signal_emit_by_name (self, "paused", TRUE);
#line 505 "TimedQueue.c"
}


void timed_queue_unpause (TimedQueue* self) {
	gboolean _tmp0_;
#line 108 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (IS_TIMED_QUEUE (self));
#line 109 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->paused_state;
#line 109 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!_tmp0_) {
#line 110 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return;
#line 519 "TimedQueue.c"
	}
#line 112 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->paused_state = FALSE;
#line 114 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_signal_emit_by_name (self, "paused", FALSE);
#line 525 "TimedQueue.c"
}


static void timed_queue_real_clear (TimedQueue* self) {
	SortedList* _tmp0_;
#line 118 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->queue;
#line 118 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	gee_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection));
#line 535 "TimedQueue.c"
}


void timed_queue_clear (TimedQueue* self) {
#line 117 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (IS_TIMED_QUEUE (self));
#line 117 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_GET_CLASS (self)->clear (self);
#line 544 "TimedQueue.c"
}


static gboolean timed_queue_real_contains (TimedQueue* self, gconstpointer item) {
	gboolean result = FALSE;
	{
		SortedList* _tmp0_;
		GeeIterator* _tmp1_ = NULL;
		GeeIterator* _e_it;
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp0_ = self->priv->queue;
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_e_it = _tmp1_;
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		while (TRUE) {
#line 562 "TimedQueue.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_ = FALSE;
			GeeIterator* _tmp4_;
			gpointer _tmp5_ = NULL;
			TimedQueueElement* e;
			GEqualFunc _tmp6_;
			gconstpointer _tmp7_;
			TimedQueueElement* _tmp8_;
			gconstpointer _tmp9_;
			gboolean _tmp10_ = FALSE;
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp2_ = _e_it;
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (!_tmp3_) {
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				break;
#line 581 "TimedQueue.c"
			}
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp4_ = _e_it;
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			e = (TimedQueueElement*) _tmp5_;
#line 123 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp6_ = self->priv->equal_func;
#line 123 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp7_ = item;
#line 123 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp8_ = e;
#line 123 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp9_ = _tmp8_->item;
#line 123 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp10_ = _tmp6_ (_tmp7_, _tmp9_);
#line 123 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (_tmp10_) {
#line 124 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				result = TRUE;
#line 124 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_timed_queue_element_unref0 (e);
#line 124 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_g_object_unref0 (_e_it);
#line 124 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				return result;
#line 609 "TimedQueue.c"
			}
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_timed_queue_element_unref0 (e);
#line 613 "TimedQueue.c"
		}
#line 122 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_g_object_unref0 (_e_it);
#line 617 "TimedQueue.c"
	}
#line 127 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = FALSE;
#line 127 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 623 "TimedQueue.c"
}


gboolean timed_queue_contains (TimedQueue* self, gconstpointer item) {
#line 121 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), FALSE);
#line 121 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return TIMED_QUEUE_GET_CLASS (self)->contains (self, item);
#line 632 "TimedQueue.c"
}


static gboolean timed_queue_real_enqueue (TimedQueue* self, gconstpointer item) {
	gboolean result = FALSE;
	SortedList* _tmp0_;
	gconstpointer _tmp1_;
	gulong _tmp2_ = 0UL;
	TimedQueueElement* _tmp3_;
	TimedQueueElement* _tmp4_;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_;
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->queue;
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = item;
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = timed_queue_calc_ready_time (self);
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp3_ = timed_queue_element_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func, _tmp1_, _tmp2_);
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp4_ = _tmp3_;
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp5_ = gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection), _tmp4_);
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp6_ = _tmp5_;
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_timed_queue_element_unref0 (_tmp4_);
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = _tmp6_;
#line 131 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 665 "TimedQueue.c"
}


gboolean timed_queue_enqueue (TimedQueue* self, gconstpointer item) {
#line 130 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), FALSE);
#line 130 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return TIMED_QUEUE_GET_CLASS (self)->enqueue (self, item);
#line 674 "TimedQueue.c"
}


static gboolean timed_queue_real_enqueue_many (TimedQueue* self, GeeCollection* items) {
	gboolean result = FALSE;
	gulong _tmp0_ = 0UL;
	gulong ready_time;
	GeeArrayList* _tmp1_;
	GeeArrayList* elements;
	SortedList* _tmp13_;
	GeeArrayList* _tmp14_;
	gboolean _tmp15_ = FALSE;
#line 134 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (items), FALSE);
#line 135 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = timed_queue_calc_ready_time (self);
#line 135 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	ready_time = _tmp0_;
#line 137 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = gee_array_list_new (TIMED_QUEUE_TYPE_ELEMENT, (GBoxedCopyFunc) timed_queue_element_ref, timed_queue_element_unref, NULL);
#line 137 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	elements = _tmp1_;
#line 697 "TimedQueue.c"
	{
		GeeCollection* _tmp2_;
		GeeIterator* _tmp3_ = NULL;
		GeeIterator* _item_it;
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp2_ = items;
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp3_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ITERABLE, GeeIterable));
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_item_it = _tmp3_;
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		while (TRUE) {
#line 710 "TimedQueue.c"
			GeeIterator* _tmp4_;
			gboolean _tmp5_ = FALSE;
			GeeIterator* _tmp6_;
			gpointer _tmp7_ = NULL;
			gpointer item;
			GeeArrayList* _tmp8_;
			gconstpointer _tmp9_;
			gulong _tmp10_;
			TimedQueueElement* _tmp11_;
			TimedQueueElement* _tmp12_;
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp4_ = _item_it;
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (!_tmp5_) {
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				break;
#line 729 "TimedQueue.c"
			}
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp6_ = _item_it;
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			item = _tmp7_;
#line 139 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp8_ = elements;
#line 139 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp9_ = item;
#line 139 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp10_ = ready_time;
#line 139 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp11_ = timed_queue_element_new (self->priv->g_type, (GBoxedCopyFunc) self->priv->g_dup_func, self->priv->g_destroy_func, _tmp9_, _tmp10_);
#line 139 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp12_ = _tmp11_;
#line 139 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp12_);
#line 139 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_timed_queue_element_unref0 (_tmp12_);
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			((item == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (item = (self->priv->g_destroy_func (item), NULL));
#line 753 "TimedQueue.c"
		}
#line 138 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_g_object_unref0 (_item_it);
#line 757 "TimedQueue.c"
	}
#line 141 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp13_ = self->priv->queue;
#line 141 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp14_ = elements;
#line 141 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp15_ = sorted_list_add_list (_tmp13_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GEE_TYPE_LIST, GeeList));
#line 141 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = _tmp15_;
#line 141 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_g_object_unref0 (elements);
#line 141 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 771 "TimedQueue.c"
}


gboolean timed_queue_enqueue_many (TimedQueue* self, GeeCollection* items) {
#line 134 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), FALSE);
#line 134 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return TIMED_QUEUE_GET_CLASS (self)->enqueue_many (self, items);
#line 780 "TimedQueue.c"
}


static gboolean timed_queue_real_remove_first (TimedQueue* self, gconstpointer item) {
	gboolean result = FALSE;
	SortedList* _tmp0_;
	GeeIterator* _tmp1_ = NULL;
	GeeIterator* iter;
#line 145 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->queue;
#line 145 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 145 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	iter = _tmp1_;
#line 146 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	while (TRUE) {
#line 797 "TimedQueue.c"
		GeeIterator* _tmp2_;
		gboolean _tmp3_ = FALSE;
		GeeIterator* _tmp4_;
		gpointer _tmp5_ = NULL;
		TimedQueueElement* e;
		GEqualFunc _tmp6_;
		gconstpointer _tmp7_;
		TimedQueueElement* _tmp8_;
		gconstpointer _tmp9_;
		gboolean _tmp10_ = FALSE;
#line 146 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp2_ = iter;
#line 146 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp3_ = gee_iterator_next (_tmp2_);
#line 146 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		if (!_tmp3_) {
#line 146 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			break;
#line 816 "TimedQueue.c"
		}
#line 147 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp4_ = iter;
#line 147 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp5_ = gee_iterator_get (_tmp4_);
#line 147 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		e = (TimedQueueElement*) _tmp5_;
#line 148 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp6_ = self->priv->equal_func;
#line 148 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp7_ = item;
#line 148 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp8_ = e;
#line 148 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp9_ = _tmp8_->item;
#line 148 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp10_ = _tmp6_ (_tmp7_, _tmp9_);
#line 148 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		if (_tmp10_) {
#line 836 "TimedQueue.c"
			GeeIterator* _tmp11_;
#line 149 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp11_ = iter;
#line 149 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			gee_iterator_remove (_tmp11_);
#line 151 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			result = TRUE;
#line 151 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_timed_queue_element_unref0 (e);
#line 151 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_g_object_unref0 (iter);
#line 151 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			return result;
#line 850 "TimedQueue.c"
		}
#line 146 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_timed_queue_element_unref0 (e);
#line 854 "TimedQueue.c"
	}
#line 155 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = FALSE;
#line 155 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_g_object_unref0 (iter);
#line 155 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 862 "TimedQueue.c"
}


gboolean timed_queue_remove_first (TimedQueue* self, gconstpointer item) {
#line 144 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), FALSE);
#line 144 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return TIMED_QUEUE_GET_CLASS (self)->remove_first (self, item);
#line 871 "TimedQueue.c"
}


static gulong timed_queue_calc_ready_time (TimedQueue* self) {
	gulong result = 0UL;
	gulong _tmp0_ = 0UL;
	guint _tmp1_;
#line 164 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), 0UL);
#line 165 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = now_ms ();
#line 165 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = self->priv->hold_msec;
#line 165 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = _tmp0_ + ((gulong) _tmp1_);
#line 165 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 889 "TimedQueue.c"
}


static gboolean timed_queue_on_heartbeat (TimedQueue* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
	gulong now;
#line 168 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), FALSE);
#line 169 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->paused_state;
#line 169 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp0_) {
#line 170 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		result = TRUE;
#line 170 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return result;
#line 907 "TimedQueue.c"
	}
#line 172 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	now = (gulong) 0;
#line 911 "TimedQueue.c"
	{
		gboolean _tmp1_;
#line 174 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp1_ = TRUE;
#line 174 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		while (TRUE) {
#line 918 "TimedQueue.c"
			gboolean _tmp2_;
			SortedList* _tmp3_;
			gint _tmp4_;
			gint _tmp5_;
			SortedList* _tmp6_;
			gpointer _tmp7_ = NULL;
			TimedQueueElement* head;
			TimedQueueElement* _tmp8_;
			gulong _tmp9_;
			TimedQueueElement* _tmp11_;
			gulong _tmp12_;
			gulong _tmp13_;
			gboolean _tmp14_ = FALSE;
			guint _tmp15_;
			gboolean _tmp19_;
			SortedList* _tmp20_;
			gpointer _tmp21_ = NULL;
			TimedQueueElement* h;
			TimedQueueElement* _tmp22_;
			TimedQueueElement* _tmp23_;
			TimedQueueElement* _tmp24_;
			gconstpointer _tmp25_;
			gulong _tmp26_;
			guint _tmp27_;
#line 174 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp2_ = _tmp1_;
#line 174 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (!_tmp2_) {
#line 947 "TimedQueue.c"
			}
#line 174 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp1_ = FALSE;
#line 175 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp3_ = self->priv->queue;
#line 175 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 175 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp5_ = _tmp4_;
#line 175 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (_tmp5_ == 0) {
#line 176 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				break;
#line 961 "TimedQueue.c"
			}
#line 178 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp6_ = self->priv->queue;
#line 178 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp7_ = sorted_list_get_at (_tmp6_, 0);
#line 178 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			head = (TimedQueueElement*) _tmp7_;
#line 179 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp8_ = head;
#line 179 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_vala_assert (_tmp8_ != NULL, "head != null");
#line 181 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp9_ = now;
#line 181 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (_tmp9_ == ((gulong) 0)) {
#line 977 "TimedQueue.c"
				gulong _tmp10_ = 0UL;
#line 182 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp10_ = now_ms ();
#line 182 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				now = _tmp10_;
#line 983 "TimedQueue.c"
			}
#line 184 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp11_ = head;
#line 184 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp12_ = _tmp11_->ready;
#line 184 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp13_ = now;
#line 184 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (_tmp12_ > _tmp13_) {
#line 185 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_timed_queue_element_unref0 (head);
#line 185 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				break;
#line 997 "TimedQueue.c"
			}
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp15_ = self->priv->dequeue_spacing_msec;
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (_tmp15_ != ((guint) 0)) {
#line 1003 "TimedQueue.c"
				gulong _tmp16_;
				gulong _tmp17_;
				guint _tmp18_;
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp16_ = now;
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp17_ = self->priv->last_dequeue;
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp18_ = self->priv->dequeue_spacing_msec;
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp14_ = (_tmp16_ - _tmp17_) < ((gulong) _tmp18_);
#line 1015 "TimedQueue.c"
			} else {
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp14_ = FALSE;
#line 1019 "TimedQueue.c"
			}
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp19_ = _tmp14_;
#line 188 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (_tmp19_) {
#line 189 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_timed_queue_element_unref0 (head);
#line 189 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				break;
#line 1029 "TimedQueue.c"
			}
#line 191 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp20_ = self->priv->queue;
#line 191 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp21_ = sorted_list_remove_at (_tmp20_, 0);
#line 191 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			h = (TimedQueueElement*) _tmp21_;
#line 192 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp22_ = head;
#line 192 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp23_ = h;
#line 192 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_vala_assert (_tmp22_ == _tmp23_, "head == h");
#line 194 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp24_ = head;
#line 194 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp25_ = _tmp24_->item;
#line 194 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			timed_queue_notify_dequeued (self, _tmp25_);
#line 195 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp26_ = now;
#line 195 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			self->priv->last_dequeue = _tmp26_;
#line 199 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp27_ = self->priv->dequeue_spacing_msec;
#line 199 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (_tmp27_ != ((guint) 0)) {
#line 200 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_timed_queue_element_unref0 (h);
#line 200 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_timed_queue_element_unref0 (head);
#line 200 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				break;
#line 1063 "TimedQueue.c"
			}
#line 174 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_timed_queue_element_unref0 (h);
#line 174 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_timed_queue_element_unref0 (head);
#line 1069 "TimedQueue.c"
		}
	}
#line 203 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = TRUE;
#line 203 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 1076 "TimedQueue.c"
}


gint timed_queue_get_size (TimedQueue* self) {
#line 159 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (IS_TIMED_QUEUE (self), 0);
#line 159 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return TIMED_QUEUE_GET_CLASS (self)->get_size (self);
#line 1085 "TimedQueue.c"
}


static gint timed_queue_real_get_size (TimedQueue* base) {
	gint result;
	TimedQueue* self;
	SortedList* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 159 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = base;
#line 160 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->queue;
#line 160 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection));
#line 160 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = _tmp1_;
#line 160 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = _tmp2_;
#line 160 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 1107 "TimedQueue.c"
}


static void timed_queue_real_paused (TimedQueue* self, gboolean is_paused) {
}


static TimedQueueElement* timed_queue_element_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, gconstpointer item, gulong ready) {
	TimedQueueElement* self = NULL;
	gconstpointer _tmp0_;
	gpointer _tmp1_;
	gulong _tmp2_;
#line 26 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = (TimedQueueElement*) g_type_create_instance (object_type);
#line 26 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_type = g_type;
#line 26 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_dup_func = g_dup_func;
#line 26 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_destroy_func = g_destroy_func;
#line 27 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = item;
#line 27 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = ((_tmp0_ != NULL) && (g_dup_func != NULL)) ? g_dup_func ((gpointer) _tmp0_) : ((gpointer) _tmp0_);
#line 27 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_g_destroy_func0 (self->item);
#line 27 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->item = _tmp1_;
#line 28 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = ready;
#line 28 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->ready = _tmp2_;
#line 26 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return self;
#line 1142 "TimedQueue.c"
}


static TimedQueueElement* timed_queue_element_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, gconstpointer item, gulong ready) {
#line 26 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return timed_queue_element_construct (TIMED_QUEUE_TYPE_ELEMENT, g_type, g_dup_func, g_destroy_func, item, ready);
#line 1149 "TimedQueue.c"
}


static gint64 timed_queue_element_comparator (void* a, void* b) {
	gint64 result = 0LL;
	void* _tmp0_;
	gulong _tmp1_;
	void* _tmp2_;
	gulong _tmp3_;
#line 32 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = a;
#line 32 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST ((TimedQueueElement*) _tmp0_, TIMED_QUEUE_TYPE_ELEMENT, TimedQueueElement)->ready;
#line 32 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = b;
#line 32 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST ((TimedQueueElement*) _tmp2_, TIMED_QUEUE_TYPE_ELEMENT, TimedQueueElement)->ready;
#line 32 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = ((gint64) _tmp1_) - ((gint64) _tmp3_);
#line 32 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 1171 "TimedQueue.c"
}


static void timed_queue_value_element_init (GValue* value) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	value->data[0].v_pointer = NULL;
#line 1178 "TimedQueue.c"
}


static void timed_queue_value_element_free_value (GValue* value) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (value->data[0].v_pointer) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		timed_queue_element_unref (value->data[0].v_pointer);
#line 1187 "TimedQueue.c"
	}
}


static void timed_queue_value_element_copy_value (const GValue* src_value, GValue* dest_value) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (src_value->data[0].v_pointer) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		dest_value->data[0].v_pointer = timed_queue_element_ref (src_value->data[0].v_pointer);
#line 1197 "TimedQueue.c"
	} else {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1201 "TimedQueue.c"
	}
}


static gpointer timed_queue_value_element_peek_pointer (const GValue* value) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return value->data[0].v_pointer;
#line 1209 "TimedQueue.c"
}


static gchar* timed_queue_value_element_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (collect_values[0].v_pointer) {
#line 1216 "TimedQueue.c"
		TimedQueueElement* object;
		object = collect_values[0].v_pointer;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		if (object->parent_instance.g_class == NULL) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1223 "TimedQueue.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1227 "TimedQueue.c"
		}
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = timed_queue_element_ref (object);
#line 1231 "TimedQueue.c"
	} else {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = NULL;
#line 1235 "TimedQueue.c"
	}
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return NULL;
#line 1239 "TimedQueue.c"
}


static gchar* timed_queue_value_element_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	TimedQueueElement** object_p;
	object_p = collect_values[0].v_pointer;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!object_p) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1250 "TimedQueue.c"
	}
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!value->data[0].v_pointer) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		*object_p = NULL;
#line 1256 "TimedQueue.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		*object_p = value->data[0].v_pointer;
#line 1260 "TimedQueue.c"
	} else {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		*object_p = timed_queue_element_ref (value->data[0].v_pointer);
#line 1264 "TimedQueue.c"
	}
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return NULL;
#line 1268 "TimedQueue.c"
}


static GParamSpec* timed_queue_param_spec_element (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	TimedQueueParamSpecElement* spec;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TIMED_QUEUE_TYPE_ELEMENT), NULL);
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return G_PARAM_SPEC (spec);
#line 1282 "TimedQueue.c"
}


static gpointer timed_queue_value_get_element (const GValue* value) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TIMED_QUEUE_TYPE_ELEMENT), NULL);
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return value->data[0].v_pointer;
#line 1291 "TimedQueue.c"
}


static void timed_queue_value_set_element (GValue* value, gpointer v_object) {
	TimedQueueElement* old;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TIMED_QUEUE_TYPE_ELEMENT));
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	old = value->data[0].v_pointer;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (v_object) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TIMED_QUEUE_TYPE_ELEMENT));
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = v_object;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		timed_queue_element_ref (value->data[0].v_pointer);
#line 1311 "TimedQueue.c"
	} else {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = NULL;
#line 1315 "TimedQueue.c"
	}
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (old) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		timed_queue_element_unref (old);
#line 1321 "TimedQueue.c"
	}
}


static void timed_queue_value_take_element (GValue* value, gpointer v_object) {
	TimedQueueElement* old;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TIMED_QUEUE_TYPE_ELEMENT));
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	old = value->data[0].v_pointer;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (v_object) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TIMED_QUEUE_TYPE_ELEMENT));
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = v_object;
#line 1340 "TimedQueue.c"
	} else {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = NULL;
#line 1344 "TimedQueue.c"
	}
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (old) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		timed_queue_element_unref (old);
#line 1350 "TimedQueue.c"
	}
}


static void timed_queue_element_class_init (TimedQueueElementClass * klass) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	timed_queue_element_parent_class = g_type_class_peek_parent (klass);
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_ELEMENT_CLASS (klass)->finalize = timed_queue_element_finalize;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_type_class_add_private (klass, sizeof (TimedQueueElementPrivate));
#line 1362 "TimedQueue.c"
}


static void timed_queue_element_instance_init (TimedQueueElement * self) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv = TIMED_QUEUE_ELEMENT_GET_PRIVATE (self);
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->ref_count = 1;
#line 1371 "TimedQueue.c"
}


static void timed_queue_element_finalize (TimedQueueElement* obj) {
	TimedQueueElement * self;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TIMED_QUEUE_TYPE_ELEMENT, TimedQueueElement);
#line 23 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	((self->item == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->item = (self->priv->g_destroy_func (self->item), NULL));
#line 1381 "TimedQueue.c"
}


static GType timed_queue_element_get_type (void) {
	static volatile gsize timed_queue_element_type_id__volatile = 0;
	if (g_once_init_enter (&timed_queue_element_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { timed_queue_value_element_init, timed_queue_value_element_free_value, timed_queue_value_element_copy_value, timed_queue_value_element_peek_pointer, "p", timed_queue_value_element_collect_value, "p", timed_queue_value_element_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (TimedQueueElementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) timed_queue_element_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TimedQueueElement), 0, (GInstanceInitFunc) timed_queue_element_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType timed_queue_element_type_id;
		timed_queue_element_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TimedQueueElement", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&timed_queue_element_type_id__volatile, timed_queue_element_type_id);
	}
	return timed_queue_element_type_id__volatile;
}


static gpointer timed_queue_element_ref (gpointer instance) {
	TimedQueueElement* self;
	self = instance;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_atomic_int_inc (&self->ref_count);
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return instance;
#line 1406 "TimedQueue.c"
}


static void timed_queue_element_unref (gpointer instance) {
	TimedQueueElement* self;
	self = instance;
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		TIMED_QUEUE_ELEMENT_GET_CLASS (self)->finalize (self);
#line 22 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1419 "TimedQueue.c"
	}
}


static void value_timed_queue_init (GValue* value) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	value->data[0].v_pointer = NULL;
#line 1427 "TimedQueue.c"
}


static void value_timed_queue_free_value (GValue* value) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (value->data[0].v_pointer) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		timed_queue_unref (value->data[0].v_pointer);
#line 1436 "TimedQueue.c"
	}
}


static void value_timed_queue_copy_value (const GValue* src_value, GValue* dest_value) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (src_value->data[0].v_pointer) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		dest_value->data[0].v_pointer = timed_queue_ref (src_value->data[0].v_pointer);
#line 1446 "TimedQueue.c"
	} else {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1450 "TimedQueue.c"
	}
}


static gpointer value_timed_queue_peek_pointer (const GValue* value) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return value->data[0].v_pointer;
#line 1458 "TimedQueue.c"
}


static gchar* value_timed_queue_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (collect_values[0].v_pointer) {
#line 1465 "TimedQueue.c"
		TimedQueue* object;
		object = collect_values[0].v_pointer;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		if (object->parent_instance.g_class == NULL) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1472 "TimedQueue.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1476 "TimedQueue.c"
		}
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = timed_queue_ref (object);
#line 1480 "TimedQueue.c"
	} else {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = NULL;
#line 1484 "TimedQueue.c"
	}
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return NULL;
#line 1488 "TimedQueue.c"
}


static gchar* value_timed_queue_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	TimedQueue** object_p;
	object_p = collect_values[0].v_pointer;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!object_p) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1499 "TimedQueue.c"
	}
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!value->data[0].v_pointer) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		*object_p = NULL;
#line 1505 "TimedQueue.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		*object_p = value->data[0].v_pointer;
#line 1509 "TimedQueue.c"
	} else {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		*object_p = timed_queue_ref (value->data[0].v_pointer);
#line 1513 "TimedQueue.c"
	}
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return NULL;
#line 1517 "TimedQueue.c"
}


GParamSpec* param_spec_timed_queue (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecTimedQueue* spec;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_TIMED_QUEUE), NULL);
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return G_PARAM_SPEC (spec);
#line 1531 "TimedQueue.c"
}


gpointer value_get_timed_queue (const GValue* value) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TIMED_QUEUE), NULL);
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return value->data[0].v_pointer;
#line 1540 "TimedQueue.c"
}


void value_set_timed_queue (GValue* value, gpointer v_object) {
	TimedQueue* old;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TIMED_QUEUE));
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	old = value->data[0].v_pointer;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (v_object) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TIMED_QUEUE));
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = v_object;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		timed_queue_ref (value->data[0].v_pointer);
#line 1560 "TimedQueue.c"
	} else {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = NULL;
#line 1564 "TimedQueue.c"
	}
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (old) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		timed_queue_unref (old);
#line 1570 "TimedQueue.c"
	}
}


void value_take_timed_queue (GValue* value, gpointer v_object) {
	TimedQueue* old;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TIMED_QUEUE));
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	old = value->data[0].v_pointer;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (v_object) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TIMED_QUEUE));
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = v_object;
#line 1589 "TimedQueue.c"
	} else {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		value->data[0].v_pointer = NULL;
#line 1593 "TimedQueue.c"
	}
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (old) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		timed_queue_unref (old);
#line 1599 "TimedQueue.c"
	}
}


static void timed_queue_class_init (TimedQueueClass * klass) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	timed_queue_parent_class = g_type_class_peek_parent (klass);
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->finalize = timed_queue_finalize;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_type_class_add_private (klass, sizeof (TimedQueuePrivate));
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->notify_dequeued = timed_queue_real_notify_dequeued;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->clear = timed_queue_real_clear;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->contains = timed_queue_real_contains;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->enqueue = timed_queue_real_enqueue;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->enqueue_many = timed_queue_real_enqueue_many;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->remove_first = timed_queue_real_remove_first;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->paused = timed_queue_real_paused;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->get_size = timed_queue_real_get_size;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_signal_new ("paused", TYPE_TIMED_QUEUE, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (TimedQueueClass, paused), NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
#line 1629 "TimedQueue.c"
}


static void timed_queue_instance_init (TimedQueue * self) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv = TIMED_QUEUE_GET_PRIVATE (self);
#line 40 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->timer_id = (guint) 0;
#line 42 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->dequeue_spacing_msec = (guint) 0;
#line 43 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->last_dequeue = (gulong) 0;
#line 44 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->paused_state = FALSE;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->ref_count = 1;
#line 1646 "TimedQueue.c"
}


static void timed_queue_finalize (TimedQueue* obj) {
	TimedQueue * self;
	guint _tmp0_;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TIMED_QUEUE, TimedQueue);
#line 65 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->timer_id;
#line 65 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 1659 "TimedQueue.c"
		guint _tmp1_;
#line 66 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp1_ = self->priv->timer_id;
#line 66 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_source_remove (_tmp1_);
#line 1665 "TimedQueue.c"
	}
#line 41 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_g_object_unref0 (self->priv->queue);
#line 1669 "TimedQueue.c"
}


GType timed_queue_get_type (void) {
	static volatile gsize timed_queue_type_id__volatile = 0;
	if (g_once_init_enter (&timed_queue_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_timed_queue_init, value_timed_queue_free_value, value_timed_queue_copy_value, value_timed_queue_peek_pointer, "p", value_timed_queue_collect_value, "p", value_timed_queue_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (TimedQueueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) timed_queue_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TimedQueue), 0, (GInstanceInitFunc) timed_queue_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType timed_queue_type_id;
		timed_queue_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TimedQueue", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&timed_queue_type_id__volatile, timed_queue_type_id);
	}
	return timed_queue_type_id__volatile;
}


gpointer timed_queue_ref (gpointer instance) {
	TimedQueue* self;
	self = instance;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_atomic_int_inc (&self->ref_count);
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return instance;
#line 1694 "TimedQueue.c"
}


void timed_queue_unref (gpointer instance) {
	TimedQueue* self;
	self = instance;
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		TIMED_QUEUE_GET_CLASS (self)->finalize (self);
#line 21 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1707 "TimedQueue.c"
	}
}


HashTimedQueue* hash_timed_queue_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, guint hold_msec, DequeuedCallback callback, void* callback_target, GHashFunc hash_func, GEqualFunc equal_func, gint priority) {
	HashTimedQueue* self = NULL;
	guint _tmp0_;
	DequeuedCallback _tmp1_;
	void* _tmp1__target;
	GEqualFunc _tmp2_;
	gint _tmp3_;
	GHashFunc _tmp4_;
	GEqualFunc _tmp5_;
	GeeHashMap* _tmp6_;
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = hold_msec;
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = callback;
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1__target = callback_target;
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = equal_func;
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp3_ = priority;
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = (HashTimedQueue*) timed_queue_construct (object_type, g_type, (GBoxedCopyFunc) g_dup_func, g_destroy_func, _tmp0_, _tmp1_, _tmp1__target, _tmp2_, _tmp3_);
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_type = g_type;
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_dup_func = g_dup_func;
#line 214 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->g_destroy_func = g_destroy_func;
#line 216 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp4_ = hash_func;
#line 216 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp5_ = equal_func;
#line 216 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp6_ = gee_hash_map_new (g_type, (GBoxedCopyFunc) g_dup_func, g_destroy_func, G_TYPE_INT, NULL, NULL, _tmp4_, _tmp5_, NULL);
#line 216 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_g_object_unref0 (self->priv->item_count);
#line 216 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv->item_count = _tmp6_;
#line 212 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return self;
#line 1752 "TimedQueue.c"
}


HashTimedQueue* hash_timed_queue_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, guint hold_msec, DequeuedCallback callback, void* callback_target, GHashFunc hash_func, GEqualFunc equal_func, gint priority) {
#line 212 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return hash_timed_queue_construct (TYPE_HASH_TIMED_QUEUE, g_type, g_dup_func, g_destroy_func, hold_msec, callback, callback_target, hash_func, equal_func, priority);
#line 1759 "TimedQueue.c"
}


static void hash_timed_queue_real_notify_dequeued (TimedQueue* base, gconstpointer item) {
	HashTimedQueue * self;
	gconstpointer _tmp0_;
	gconstpointer _tmp1_;
#line 219 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_HASH_TIMED_QUEUE, HashTimedQueue);
#line 220 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = item;
#line 220 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	hash_timed_queue_removed (self, _tmp0_);
#line 222 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = item;
#line 222 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (hash_timed_queue_parent_class)->notify_dequeued (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TIMED_QUEUE, TimedQueue), _tmp1_);
#line 1777 "TimedQueue.c"
}


static void hash_timed_queue_real_clear (TimedQueue* base) {
	HashTimedQueue * self;
	GeeHashMap* _tmp0_;
#line 225 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_HASH_TIMED_QUEUE, HashTimedQueue);
#line 226 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->item_count;
#line 226 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	gee_abstract_map_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap));
#line 228 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (hash_timed_queue_parent_class)->clear (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TIMED_QUEUE, TimedQueue));
#line 1792 "TimedQueue.c"
}


static gboolean hash_timed_queue_real_contains (TimedQueue* base, gconstpointer item) {
	HashTimedQueue * self;
	gboolean result = FALSE;
	GeeHashMap* _tmp0_;
	gconstpointer _tmp1_;
	gboolean _tmp2_ = FALSE;
#line 231 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_HASH_TIMED_QUEUE, HashTimedQueue);
#line 232 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->item_count;
#line 232 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = item;
#line 232 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 232 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = _tmp2_;
#line 232 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 1814 "TimedQueue.c"
}


static gboolean hash_timed_queue_real_enqueue (TimedQueue* base, gconstpointer item) {
	HashTimedQueue * self;
	gboolean result = FALSE;
	gconstpointer _tmp0_;
	gboolean _tmp1_ = FALSE;
	gint _tmp2_ = 0;
	GeeHashMap* _tmp3_;
	gconstpointer _tmp4_;
	gboolean _tmp5_ = FALSE;
	GeeHashMap* _tmp9_;
	gconstpointer _tmp10_;
	gint _tmp11_;
#line 235 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_HASH_TIMED_QUEUE, HashTimedQueue);
#line 236 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = item;
#line 236 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = TIMED_QUEUE_CLASS (hash_timed_queue_parent_class)->enqueue (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TIMED_QUEUE, TimedQueue), _tmp0_);
#line 236 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!_tmp1_) {
#line 237 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		result = FALSE;
#line 237 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return result;
#line 1842 "TimedQueue.c"
	}
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp3_ = self->priv->item_count;
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp4_ = item;
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp5_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp4_);
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp5_) {
#line 1852 "TimedQueue.c"
		GeeHashMap* _tmp6_;
		gconstpointer _tmp7_;
		gpointer _tmp8_ = NULL;
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp6_ = self->priv->item_count;
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp7_ = item;
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp8_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp7_);
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp2_ = ((gint) ((gintptr) _tmp8_)) + 1;
#line 1864 "TimedQueue.c"
	} else {
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp2_ = 1;
#line 1868 "TimedQueue.c"
	}
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp9_ = self->priv->item_count;
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp10_ = item;
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp11_ = _tmp2_;
#line 239 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp10_, (gpointer) ((gintptr) _tmp11_));
#line 241 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = TRUE;
#line 241 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 1882 "TimedQueue.c"
}


static gboolean hash_timed_queue_real_enqueue_many (TimedQueue* base, GeeCollection* items) {
	HashTimedQueue * self;
	gboolean result = FALSE;
	GeeCollection* _tmp0_;
	gboolean _tmp1_ = FALSE;
#line 244 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_HASH_TIMED_QUEUE, HashTimedQueue);
#line 244 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (items), FALSE);
#line 245 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = items;
#line 245 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = TIMED_QUEUE_CLASS (hash_timed_queue_parent_class)->enqueue_many (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TIMED_QUEUE, TimedQueue), _tmp0_);
#line 245 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!_tmp1_) {
#line 246 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		result = FALSE;
#line 246 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return result;
#line 1905 "TimedQueue.c"
	}
	{
		GeeCollection* _tmp2_;
		GeeIterator* _tmp3_ = NULL;
		GeeIterator* _item_it;
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp2_ = items;
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp3_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ITERABLE, GeeIterable));
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_item_it = _tmp3_;
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		while (TRUE) {
#line 1919 "TimedQueue.c"
			GeeIterator* _tmp4_;
			gboolean _tmp5_ = FALSE;
			GeeIterator* _tmp6_;
			gpointer _tmp7_ = NULL;
			gpointer item;
			gint _tmp8_ = 0;
			GeeHashMap* _tmp9_;
			gconstpointer _tmp10_;
			gboolean _tmp11_ = FALSE;
			GeeHashMap* _tmp15_;
			gconstpointer _tmp16_;
			gint _tmp17_;
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp4_ = _item_it;
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (!_tmp5_) {
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				break;
#line 1940 "TimedQueue.c"
			}
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp6_ = _item_it;
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			item = _tmp7_;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp9_ = self->priv->item_count;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp10_ = item;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp11_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp10_);
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			if (_tmp11_) {
#line 1956 "TimedQueue.c"
				GeeHashMap* _tmp12_;
				gconstpointer _tmp13_;
				gpointer _tmp14_ = NULL;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp12_ = self->priv->item_count;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp13_ = item;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp14_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp13_);
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp8_ = ((gint) ((gintptr) _tmp14_)) + 1;
#line 1968 "TimedQueue.c"
			} else {
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
				_tmp8_ = 1;
#line 1972 "TimedQueue.c"
			}
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp15_ = self->priv->item_count;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp16_ = item;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			_tmp17_ = _tmp8_;
#line 249 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp16_, (gpointer) ((gintptr) _tmp17_));
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
			((item == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (item = (self->priv->g_destroy_func (item), NULL));
#line 1984 "TimedQueue.c"
		}
#line 248 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_g_object_unref0 (_item_it);
#line 1988 "TimedQueue.c"
	}
#line 251 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = TRUE;
#line 251 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 1994 "TimedQueue.c"
}


static gboolean hash_timed_queue_real_remove_first (TimedQueue* base, gconstpointer item) {
	HashTimedQueue * self;
	gboolean result = FALSE;
	gconstpointer _tmp0_;
	gboolean _tmp1_ = FALSE;
	gconstpointer _tmp2_;
#line 254 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_HASH_TIMED_QUEUE, HashTimedQueue);
#line 255 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = item;
#line 255 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = TIMED_QUEUE_CLASS (hash_timed_queue_parent_class)->remove_first (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TIMED_QUEUE, TimedQueue), _tmp0_);
#line 255 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!_tmp1_) {
#line 256 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		result = FALSE;
#line 256 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return result;
#line 2016 "TimedQueue.c"
	}
#line 258 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = item;
#line 258 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	hash_timed_queue_removed (self, _tmp2_);
#line 260 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	result = TRUE;
#line 260 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	return result;
#line 2026 "TimedQueue.c"
}


static void hash_timed_queue_removed (HashTimedQueue* self, gconstpointer item) {
	GeeHashMap* _tmp0_;
	gconstpointer _tmp1_;
	gboolean _tmp2_ = FALSE;
	GeeHashMap* _tmp3_;
	gconstpointer _tmp4_;
	gpointer _tmp5_ = NULL;
	gint count;
	gint _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
#line 263 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_return_if_fail (IS_HASH_TIMED_QUEUE (self));
#line 266 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp0_ = self->priv->item_count;
#line 266 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp1_ = item;
#line 266 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp2_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 266 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (!_tmp2_) {
#line 267 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		return;
#line 2053 "TimedQueue.c"
	}
#line 269 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp3_ = self->priv->item_count;
#line 269 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp4_ = item;
#line 269 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp5_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp4_);
#line 269 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	count = (gint) ((gintptr) _tmp5_);
#line 270 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp6_ = count;
#line 270 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_vala_assert (_tmp6_ > 0, "count > 0");
#line 272 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp7_ = count;
#line 272 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	count = _tmp7_ - 1;
#line 272 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_tmp8_ = count;
#line 272 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	if (_tmp8_ == 0) {
#line 2075 "TimedQueue.c"
		GeeHashMap* _tmp9_;
		gconstpointer _tmp10_;
#line 273 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp9_ = self->priv->item_count;
#line 273 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp10_ = item;
#line 273 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp10_, NULL);
#line 2084 "TimedQueue.c"
	} else {
		GeeHashMap* _tmp11_;
		gconstpointer _tmp12_;
		gint _tmp13_;
#line 275 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp11_ = self->priv->item_count;
#line 275 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp12_ = item;
#line 275 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		_tmp13_ = count;
#line 275 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
		gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp12_, (gpointer) ((gintptr) _tmp13_));
#line 2097 "TimedQueue.c"
	}
}


static void hash_timed_queue_class_init (HashTimedQueueClass * klass) {
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	hash_timed_queue_parent_class = g_type_class_peek_parent (klass);
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->finalize = hash_timed_queue_finalize;
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	g_type_class_add_private (klass, sizeof (HashTimedQueuePrivate));
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->notify_dequeued = hash_timed_queue_real_notify_dequeued;
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->clear = hash_timed_queue_real_clear;
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->contains = hash_timed_queue_real_contains;
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->enqueue = hash_timed_queue_real_enqueue;
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->enqueue_many = hash_timed_queue_real_enqueue_many;
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (klass)->remove_first = hash_timed_queue_real_remove_first;
#line 2121 "TimedQueue.c"
}


static void hash_timed_queue_instance_init (HashTimedQueue * self) {
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self->priv = HASH_TIMED_QUEUE_GET_PRIVATE (self);
#line 2128 "TimedQueue.c"
}


static void hash_timed_queue_finalize (TimedQueue* obj) {
	HashTimedQueue * self;
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_HASH_TIMED_QUEUE, HashTimedQueue);
#line 210 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	_g_object_unref0 (self->priv->item_count);
#line 209 "/builddir/build/BUILD/shotwell-0.14.1/src/TimedQueue.vala"
	TIMED_QUEUE_CLASS (hash_timed_queue_parent_class)->finalize (obj);
#line 2140 "TimedQueue.c"
}


GType hash_timed_queue_get_type (void) {
	static volatile gsize hash_timed_queue_type_id__volatile = 0;
	if (g_once_init_enter (&hash_timed_queue_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (HashTimedQueueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) hash_timed_queue_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (HashTimedQueue), 0, (GInstanceInitFunc) hash_timed_queue_instance_init, NULL };
		GType hash_timed_queue_type_id;
		hash_timed_queue_type_id = g_type_register_static (TYPE_TIMED_QUEUE, "HashTimedQueue", &g_define_type_info, 0);
		g_once_init_leave (&hash_timed_queue_type_id__volatile, hash_timed_queue_type_id);
	}
	return hash_timed_queue_type_id__volatile;
}



